@@ -600,9 +600,13 @@ table.docutils th {
                     # ---------------------------------------------------------
                     # xref
                     if schema.xcalling:
-                        df = pd.DataFrame(
-                            schema.xcalling, index=["Xref sheet", "Xref column"]
-                        ).T
+                        try:
+                            df = pd.DataFrame(
+                                schema.xcalling,
+                                index=["Xref sheet", "Xref column", "Xref check"],
+                            ).T
+                        except:
+                            breakpoint()
                         df.index.names = ["column"]
                         df.reset_index(inplace=True)
                         table = tabulate.tabulate(
@@ -653,7 +657,11 @@ def dump_xlsx_template(schemas, output, tabs=(), excluded_tabs=None):
     # eventually filter with tabs wishlist
     schemas = data._schemas.copy()
     if tabs:
+        # restrict schemas to provided tabs
         schemas = {k: v for k, v in schemas.items() if k in tabs}
+    else:
+        # get all tabs
+        tabs = list(schemas.keys())
     if excluded_tabs:
         schemas = {k: v for k, v in schemas.items() if k not in excluded_tabs}
     # -------------------------------------------------------------------------
@@ -747,7 +755,7 @@ def dump_xlsx_template(schemas, output, tabs=(), excluded_tabs=None):
             # -----------------------------------------------------------------
             # autofit
     logging.info(f"finilized {output}")
-    return output
+    return output, cols
 
 
 def field_status(colname, schema):
