@@ -90,7 +90,13 @@ def read_excel(fpath, sheet_name=None, engine=DEFAULT_EXCEL_ENGINE):
     ret = {k: df.dropna(how="all") for k, df in df_dict.items()}
     # also clean Unnamed columns
     for tab, df in ret.items():
-        df = df[[c for c in df if not c.startswith("Unnamed: ")]]
+        try:
+            df = df[
+                [c for c in df if isinstance(c, str) and not c.startswith("Unnamed: ")]
+            ]
+        except Exception as exc:
+            logging.critical(f"cannot parse {tab=}")
+            raise
         ret[tab] = df
     return ret
 
